# eric7.Preferences.ConfigurationPages.MasterPasswordEntryDialog

Module implementing a dialog to enter or change the master password.

### Global Attributes

None

### Classes

MasterPasswordEntryDialog | Class implementing a dialog to enter or change the master password.

### Functions

None

## MasterPasswordEntryDialog

Class implementing a dialog to enter or change the master password.

### Derived from

QDialog, Ui_MasterPasswordEntryDialog

### Class Attributes

None

### Class Methods

None

### Methods

MasterPasswordEntryDialog | Constructor
__updateUI | Private slot to update the variable parts of the UI.
getCurrentPassword | Public method to get the current master password.
getMasterPassword | Public method to get the new master password.
on_currentPasswordEdit_textChanged | Private slot to handle changes of the current password.
on_newPasswordAgainEdit_textChanged | Private slot to handle changes of the new again password.
on_newPasswordEdit_textChanged | Private slot to handle changes of the new password.

### Static Methods

None

#### MasterPasswordEntryDialog (Constructor)

MasterPasswordEntryDialog(oldPasswordHash, parent=None)

Constructor

oldPasswordHash
  hash of the current password (string)
parent
  reference to the parent widget (QWidget)

#### MasterPasswordEntryDialog.__updateUI

__updateUI()

Private slot to update the variable parts of the UI.

#### MasterPasswordEntryDialog.getCurrentPassword

getCurrentPassword()

Public method to get the current master password.

Return:
  current master password (string)

#### MasterPasswordEntryDialog.getMasterPassword

getMasterPassword()

Public method to get the new master password.

Return:
  new master password (string)

#### MasterPasswordEntryDialog.on_currentPasswordEdit_textChanged

on_currentPasswordEdit_textChanged(txt)

Private slot to handle changes of the current password.

txt
  content of the edit widget (string)

#### MasterPasswordEntryDialog.on_newPasswordAgainEdit_textChanged

on_newPasswordAgainEdit_textChanged(txt)

Private slot to handle changes of the new again password.

txt
  content of the edit widget (string)

#### MasterPasswordEntryDialog.on_newPasswordEdit_textChanged

on_newPasswordEdit_textChanged(txt)

Private slot to handle changes of the new password.

txt
  content of the edit widget (string)

Up